(function ($, Drupal, once) {
// Add thumbnail hover behavior
Drupal.behaviors.filesAndFoldersThumbnailHover = {
  attach: function (context, settings) {
    let modal = $('<div class="thumbnail-modal"><img /><div class="modal-filename"></div></div>').appendTo('body');
    let modalImg = modal.find('img');
    let modalFilename = modal.find('.modal-filename');
    let timeout;

    // Use Drupal's once() function correctly
    $(once('thumbnail-hover', '.thumbnail-hover', context)).each(function () {
      const $thumbnail = $(this);
      
      $thumbnail.hover(
        function (e) { // mouseenter
          clearTimeout(timeout);
          const fullUrl = $(this).data('full-url');
          const filename = $(this).data('filename');
          
          // Show the modal with a slight delay
          timeout = setTimeout(function() {
            showEnlargedThumbnail(e, fullUrl, filename);
          }, 300); // 300ms delay before showing
        },
        function () { // mouseleave
          clearTimeout(timeout);
          modal.fadeOut(200);
        }
      );
    });

    // Hide modal when mouse leaves it
    modal.hover(
      function () {
        clearTimeout(timeout);
      },
      function () {
        modal.fadeOut(200);
      }
    );

    // Update modal position on mouse move
    $(document).on('mousemove', '.thumbnail-hover', function(e) {
      if (modal.is(':visible')) {
        const fullUrl = $(this).data('full-url');
        const filename = $(this).data('filename');
        showEnlargedThumbnail(e, fullUrl, filename);
      }
    });

    // Function to show enlarged thumbnail
    function showEnlargedThumbnail(e, fullUrl, filename) {
      // Load the image first to get its natural dimensions
      const img = new Image();
      img.onload = function() {
        // Calculate dimensions maintaining aspect ratio
        const maxWidth = window.innerWidth * 0.8;  // 80% of window width
        const maxHeight = window.innerHeight * 0.8; // 80% of window height
        
        let width = img.naturalWidth;
        let height = img.naturalHeight;
        
        if (width > maxWidth) {
          height = height * (maxWidth / width);
          width = maxWidth;
        }
        
        if (height > maxHeight) {
          width = width * (maxHeight / height);
          height = maxHeight;
        }
        
        // Set modal dimensions
        modalImg.css({
          'width': width + 'px',
          'height': height + 'px'
        });
        
        // Calculate position to ensure modal stays within viewport
        const windowWidth = $(window).width();
        const windowHeight = $(window).height();
        
        let left = e.pageX + 20;
        let top = e.pageY + 20;
        
        // Adjust if modal would go outside viewport
        if (left + width + 40 > windowWidth) {
          left = e.pageX - width - 40;
        }
        if (top + height + 40 > windowHeight) {
          top = e.pageY - height - 40;
        }
        
        // Update modal position and content
        modal.css({
          'left': left + 'px',
          'top': top + 'px'
        });
        
        modalImg.attr('src', fullUrl);
        modalFilename.text(filename);
        
        // Show the modal if not already visible
        if (!modal.is(':visible')) {
          modal.fadeIn(200);
        }
      };
      
      img.src = fullUrl;
    }
  }
};

  // Main files and folders behavior
  Drupal.behaviors.filesAndFolders = {
    attach: function (context, settings) {
      once('filesAndFolders', 'body', context).forEach(function (element) {
        // Initialize main functionalities
        loadFolderTree();
        loadRootFolders();
        initContentAreaEvents();
        initOptionsButton();

        // Add passive touch event listeners
        element.addEventListener('touchstart', handleTouchStart, { passive: true });
        element.addEventListener('touchmove', handleTouchMove, { passive: true });

        // Create folder button event
        $('.create-folder', context).on('click', function(e) {
          e.preventDefault();
          createFolder();
        });

        initAddFilesButton();
      });

      // Touch event handlers
      function handleTouchStart(e) {
        // Handle touch start event
        console.log('Touch start detected');
      }

      function handleTouchMove(e) {
        // Handle touch move event
        console.log('Touch move detected');
      }

      $(document).ready(function() {
        // Fetch the saved icon size preference
        $.get(Drupal.url('files-and-folders/get-icon-size'), function(response) {
          if (response.size) {
            $('.content-area-content').attr('data-icon-size', response.size);
            applyIconSize(response.size);
          }
        });
      
        // Initialize options and layout buttons
        $('#options-button').off('click').on('click', openOptionsModal);
        $('#layout-options-button').off('click').on('click', openLayoutOptionsModal);
      
        // Initialize search functionality
        $('#search-button').off('click').on('click', performSearch);
        $('#search-input').off('keypress').on('keypress', function(e) {
          if (e.which === 13) {
            performSearch();
          }
        });
      
        // Load saved layout
        $.get(Drupal.url('files-and-folders/get-layout'), function(response) {
          changeLayout(response.layout);
        });
      
        // Load initial content (root folders)
        loadRootFolders();
      });
      
      function loadInitialContent() {
        $.getJSON(Drupal.url('files-and-folders/get-folder-content/0'), function (data) {
          console.log("Received data:", data);
          $('.content-area-content').html(data.html);
          $('.content-area-title').text(data.folderName || 'Root');
        }).fail(function(jqXHR, textStatus, errorThrown) {
          console.error("Error loading initial content:", textStatus, errorThrown);
        });
      }

      function initFolderTree() {
        const folderItems = document.querySelectorAll('.folder-item');
        
        folderItems.forEach(item => {
          const toggle = item.querySelector('.folder-toggle');
          const folderId = item.dataset.folderId;
          
          if (toggle) {
            // Check if this folder has children
            const hasChildren = item.querySelector('.subfolder-list') !== null;
            
            if (hasChildren) {
              toggle.textContent = '▶';
              item.classList.add('has-children');
            } else {
              toggle.style.visibility = 'hidden'; // Hide toggle if no children
            }
            
            toggle.addEventListener('click', (e) => {
              e.stopPropagation();
              item.classList.toggle('expanded');
              toggle.textContent = item.classList.contains('expanded') ? '▼' : '▶';
              
              // Toggle visibility of child items
              const childList = item.querySelector('.subfolder-list');
              if (childList) {
                $(childList).slideToggle();
              }
            });
          }
          
          // Add click event listener for the folder name
          const folderName = item.querySelector('.folder-name');
          if (folderName) {
            folderName.addEventListener('click', () => {
              loadFolderContent(folderId);
              updateFolderTreeSelection(folderId);
              
              // Add 'selected' class to the clicked folder
              document.querySelectorAll('.folder-item').forEach(f => f.classList.remove('selected'));
              item.classList.add('selected');
            });
          }
      
          // Add double-click event listener for immediate navigation
          item.addEventListener('dblclick', () => {
            loadFolderContent(folderId);
            updateFolderTreeSelection(folderId);
          });
        });
      
        // Apply current icon size to the folder tree
        applyCurrentIconSize();
      }

      function loadFolderTree() {
        $.getJSON(Drupal.url('files-and-folders/get-folder-tree'), function (data) {
          var folderTree = buildFolderTree(data);
          $('#folder-tree-container').html(folderTree);
          initFolderTree();
          applyCurrentIconSize();
        }).fail(function(jqXHR, textStatus, errorThrown) {
          if (jqXHR.status === 403) {
            $('#folder-tree-container').html('<p>You do not have permission to view this folder tree.</p>');
          } else {
            console.error('Error loading folder tree:', textStatus, errorThrown);
          }
        });
      }

      function buildFolderTree(data) {
        var html = '<ul class="folder-tree">';
        data.forEach(function(item) {
          html += buildFolderTreeItem(item);
        });
        html += '</ul>';
        return html;
      }      

      function buildFolderTreeItem(item) {
        var html = '<li class="folder-item" data-folder-id="' + item.id + '">';
        html += '<div class="folder-content">';
        html += '<span class="folder-toggle"></span>';
        if (item.icon_url) {
          html += '<img src="' + item.icon_url + '" class="folder-icon" alt="Folder Icon">';
        } else {
          html += '<span class="folder-icon default-icon">📁</span>';
        }
        html += '<span class="folder-name">' + item.name + '</span>';
        html += '</div>';
        if (item.children && item.children.length > 0) {
          html += '<ul class="subfolder-list" style="display: none;">';
          item.children.forEach(function(child) {
            html += buildFolderTreeItem(child);
          });
          html += '</ul>';
        }
        html += '</li>';
        return html;
      }

      function loadRootFolders() {
        $.getJSON(Drupal.url('files-and-folders/get-root-folders'), function(data) {
          $('.content-area-content').html(data.html);
          $('.content-area-title').text(Drupal.t('Root'));
          applyCurrentLayout();
          applyCurrentIconSize();
        }).fail(function(jqXHR, textStatus, errorThrown) {
          console.error('Error loading root folders:', textStatus, errorThrown);
          $('.content-area-content').html('<p>' + Drupal.t('Error loading root folders.') + '</p>');
        });
      }

      function refreshFolderStructure() {
        loadFolderTree();
        loadRootFolders();
      }
      
      function initOptionsButton() {
        $('#options-button').on('click', function() {
          openOptionsModal();
        });
      }
      
      function openOptionsModal() {
        var $modal = $('<div id="options-modal">').dialog({
          title: Drupal.t('Options'),
          width: '300px',
          modal: true,
          dialogClass: 'files-and-folders-dialog',
          close: function() {
            $(this).remove();
          }
        });
      
        var $content = $('<div>')
          .append($('<button>')
            .text(Drupal.t('Add Root Folder'))
            .addClass('button button--primary button--add-root-folder')
            .click(function() {
              $modal.dialog('close');
              openAddRootFolderModal();
            }))
          .append($('<button>')
            .text(Drupal.t('Set Icon Size'))
            .addClass('button button--secondary button--set-icon-size')
            .click(function() {
              $modal.dialog('close');
              openSetIconSizeModal();
            }));
      
        $modal.append($content);
      }
      
      function openLayoutOptionsModal() {
        // Close any existing dialogs
        $('.ui-dialog-content').dialog('close');
      
        var $modal = $('<div id="layout-options-modal">').dialog({
          title: Drupal.t('Choose Layout'),
          width: '300px',
          modal: true,
          dialogClass: 'files-and-folders-dialog',
          close: function() {
            $(this).dialog('destroy').remove();
          }
        });
      
        var layouts = [
          {name: 'list', icon: '<svg width="24" height="24" viewBox="0 0 24 24"><path d="M3 13h2v-2H3v2zm0 4h2v-2H3v2zm0-8h2V7H3v2zm4 4h14v-2H7v2zm0 4h14v-2H7v2zM7 7v2h14V7H7z"/></svg>', label: Drupal.t('List')},
          {name: 'grid-2', icon: '<svg width="24" height="24" viewBox="0 0 24 24"><path d="M3 3v8h8V3H3zm10 0v8h8V3h-8zM3 13v8h8v-8H3zm10 0v8h8v-8h-8z"/></svg>', label: Drupal.t('2 Column Grid')},
          {name: 'grid-3', icon: '<svg width="24" height="24" viewBox="0 0 24 24"><path d="M3 3v8h5V3H3zm6.5 0v8h5V3h-5zM15 3v8h5V3h-5zM3 13v8h5v-8H3zm6.5 0v8h5v-8h-5zM15 13v8h5v-8h-5z"/></svg>', label: Drupal.t('3 Column Grid')},
          {name: 'grid-4', icon: '<svg width="24" height="24" viewBox="0 0 24 24"><path d="M3 3v4h4V3H3zm5 0v4h4V3H8zm5 0v4h4V3h-4zm5 0v4h4V3h-4zM3 8v4h4V8H3zm5 0v4h4V8H8zm5 0v4h4V8h-4zm5 0v4h4V8h-4zM3 13v4h4v-4H3zm5 0v4h4v-4H8zm5 0v4h4v-4h-4zm5 0v4h4v-4h-4zM3 18v4h4v-4H3zm5 0v4h4v-4H8zm5 0v4h4v-4h-4zm5 0v4h4v-4h-4z"/></svg>', label: Drupal.t('4 Column Grid')},
          {name: 'big-icons', icon: '<svg width="24" height="24" viewBox="0 0 24 24"><path d="M4 5h16v2H4zm0 6h16v2H4zm0 6h16v2H4z"/></svg>', label: Drupal.t('Big Icons')},
          {name: 'medium-icons', icon: '<svg width="24" height="24" viewBox="0 0 24 24"><path d="M3 5h18v2H3zm0 6h18v2H3zm0 6h18v2H3z"/></svg>', label: Drupal.t('Medium Icons')}
        ];
      
        var $content = $('<div>');
        layouts.forEach(function(layout) {
          $content.append(
            $('<button>')
              .addClass('layout-option')
              .attr('data-layout', layout.name)
              .html(layout.icon + ' ' + layout.label)
              .click(function() {
                changeLayout(layout.name);
                $modal.dialog('close');
              })
          );
        });
      
        $modal.append($content);
      }
      
      function changeLayout(layoutName) {
        $('.content-area-content').attr('data-layout', layoutName);
        
        // Save the layout preference
        $.post(Drupal.url('files-and-folders/ajax/save-layout'), {layout: layoutName})
          .done(function(response) {
            if (response.status === 'success') {
              console.log('Layout saved successfully');
              refreshCurrentContent();
              applyCurrentIconSize();
              
              // Handle specific layout adjustments
              if (layoutName === 'big-icons' || layoutName === 'medium-icons') {
                $('.item-details, .actions').hide();
              } else {
                $('.item-details, .actions').show();
              }
            } else {
              console.error('Error saving layout:', response.message);
            }
          })
          .fail(function(jqXHR, textStatus, errorThrown) {
            console.error('AJAX error:', textStatus, errorThrown);
          });
      }
      
      function refreshCurrentContent() {
        var currentFolderId = $('.content-area').data('current-folder-id');
        if (currentFolderId) {
          loadFolderContent(currentFolderId);
        } else {
          loadRootFolders();
        }
      }
      
      
      function initKebabMenu() {
        $('.kebab-menu-button').off('click').on('click', function(e) {
          e.stopPropagation();
          $(this).closest('.kebab-menu').toggleClass('active');
        });
      
        $(document).on('click', function(e) {
          if (!$(e.target).closest('.kebab-menu').length) {
            $('.kebab-menu').removeClass('active');
          }
        });
      }
      
      
      function openAddRootFolderModal() {
        var $modal = $('<div id="add-root-folder-modal">').dialog({
          title: Drupal.t('Add Root Folder'),
          width: '400px',
          modal: true,
          dialogClass: 'files-and-folders-dialog',
          close: function() {
            $(this).remove();
          }
        });
      
        var $content = $('<div>')
          .append($('<label for="root-folder-name">').text(Drupal.t('Nom du dossier')))
          .append($('<input id="root-folder-name" type="text">'))
          .append($('<label for="root-folder-icon">').text(Drupal.t('Folder Icon')))
          .append($('<input id="root-folder-icon" type="file" accept="image/*">'))
          .append($('<label>').text(Drupal.t('Allowed Roles')))
          .append($('<div id="root-folder-roles">').addClass('roles-container'));
      
        $modal.append($content);
      
        // Load roles after appending content to the modal
        $.getJSON(Drupal.url('files-and-folders/get-roles'), function(data) {
          var $rolesList = $('<ul>');
          $.each(data, function(index, role) {
            $rolesList.append(
              $('<li>').append(
                $('<label>').append(
                  $('<input>').attr({
                    type: 'checkbox',
                    name: 'allowed_roles[]',
                    value: role.id
                  })
                ).append(role.label)
              )
            );
          });
          $('#root-folder-roles').append($rolesList);
        });
      
        $modal.dialog('option', 'buttons', [
          {
            text: Drupal.t('Créer'),
            click: function() {
              var folderName = $('#root-folder-name').val();
              var iconFile = $('#root-folder-icon')[0].files[0];
              var allowedRoles = $('#root-folder-roles input:checked').map(function() {
                return this.value;
              }).get();
              createRootFolder(folderName, iconFile, allowedRoles);
              $(this).dialog('close');
            }
          },
          {
            text: Drupal.t('Annuler'),
            click: function() {
              $(this).dialog('close');
            }
          }
        ]);
      }
      
      function createRootFolder(folderName, iconFile, authorizedRoles) {
        var formData = new FormData();
        formData.append('name', folderName);
        if (iconFile) {
          formData.append('icon', iconFile);
        }
        formData.append('allowed_roles', JSON.stringify(authorizedRoles));
      
        $.ajax({
          url: Drupal.url('files-and-folders/ajax/create-root-folder'),
          method: 'POST',
          data: formData,
          processData: false,
          contentType: false,
          success: function(response) {
            if (response.status === 'success') {
              loadFolderTree();
              loadRootFolders();
            } else {
              alert(Drupal.t('Error creating root folder: @message', {'@message': response.message}));
            }
          },
          error: function(jqXHR, textStatus, errorThrown) {
            console.error('Error creating root folder:', textStatus, errorThrown);
            alert(Drupal.t('An error occurred while creating the root folder.'));
          }
        });
      }

      function openSetIconSizeModal() {
        // Close existing dialogs asynchronously
        setTimeout(function() {
          $('.ui-dialog-content').dialog('close');
        }, 0);
      
        // Create modal content asynchronously
        setTimeout(function() {
          var $modal = $('<div id="set-icon-size-modal">').dialog({
            title: Drupal.t('Set Icon Size'),
            width: '400px',
            modal: true,
            dialogClass: 'files-and-folders-dialog',
            close: function() {
              $(this).remove();
            }
          });
      
          var $content = $('<div>')
            .append($('<p>').text(Drupal.t('Select icon size:')))
            .append($('<select id="icon-size-select">')
              .append($('<option>').val('small').text(Drupal.t('Small')))
              .append($('<option>').val('medium').text(Drupal.t('Medium')))
              .append($('<option>').val('large').text(Drupal.t('Large')))
            );
      
          $modal.append($content);
      
          $modal.dialog('option', 'buttons', [
            {
              text: Drupal.t('Save'),
              click: function() {
                var selectedSize = $('#icon-size-select').val();
                saveIconSize(selectedSize);
                $(this).dialog('close');
              }
            },
            {
              text: Drupal.t('Cancel'),
              click: function() {
                $(this).dialog('close');
              }
            }
          ]);
        }, 0);
      }
      
      function saveIconSize(size) {
        $.ajax({
          url: Drupal.url('files-and-folders/ajax/save-icon-size'),
          method: 'POST',
          data: { size: size },
          success: function(response) {
            if (response.status === 'success') {
              console.log('Icon size saved successfully');
              // Apply the new icon size immediately
              $('.content-area-content').attr('data-icon-size', size);
              applyIconSize(size);
            } else {
              console.error('Error saving icon size:', response.message);
            }
          },
          error: function(jqXHR, textStatus, errorThrown) {
            console.error('AJAX error:', textStatus, errorThrown);
          }
        });
      }
      
      function initContentAreaEvents() {
        // Function to get viewer URL based on file type
        function getViewerUrl(fileUrl, fileType) {
          // Ensure fileUrl is absolute
          if (!fileUrl.startsWith('http')) {
            fileUrl = window.location.origin + fileUrl;
          }
      
          // Define file type groups
          const officeExtensions = ['doc', 'docx', 'xls', 'xlsx', 'ppt', 'pptx'];
          const imageExtensions = ['jpg', 'jpeg', 'png', 'gif', 'webp'];
          const pdfExtensions = ['pdf'];
          const csvExtensions = ['csv'];
      
          // Log URLs for debugging
          console.log('Original file URL:', fileUrl);
          
          if (imageExtensions.includes(fileType.toLowerCase())) {
            // For images, return direct URL
            return fileUrl;
          } else if (pdfExtensions.includes(fileType.toLowerCase())) {
            // For PDFs, return direct URL to be handled by browser's PDF viewer
            return fileUrl;
          } else if (csvExtensions.includes(fileType.toLowerCase()) || officeExtensions.includes(fileType.toLowerCase())) {
            // For CSV and Office files, use Google Docs Viewer
            return 'https://docs.google.com/gview?url=' + encodeURIComponent(fileUrl) + '&embedded=true';
          }
          
          return fileUrl;
        }
      
        // Function to update modal content based on file type
        function updateModal(fileUrl, fileName, fileType) {
          const viewerUrl = getViewerUrl(fileUrl, fileType);
          $('#office-online-modal .office-file-name').text(fileName);
      
          const imageExtensions = ['jpg', 'jpeg', 'png', 'gif', 'webp'];
          const pdfExtensions = ['pdf'];
          
          if (imageExtensions.includes(fileType.toLowerCase())) {
            // For images, use img tag
            $('#office-frame').hide();
            if (!$('#modal-image').length) {
              $('.office-modal-body').append('<img id="modal-image" style="max-width: 100%; max-height: 100%; object-fit: contain;">');
            }
            $('#modal-image').show().attr('src', viewerUrl);
          } else if (pdfExtensions.includes(fileType.toLowerCase())) {
            // For PDFs, use iframe with specific attributes
            $('#modal-image').hide();
            $('#office-frame').show().attr({
              'src': viewerUrl,
              'type': 'application/pdf',
              'width': '100%',
              'height': '100%'
            });
          } else {
            // For other documents, use standard iframe
            $('#modal-image').hide();
            $('#office-frame').show().attr('src', viewerUrl);
          }
      
          $('#office-online-modal').fadeIn(300);
        }
        
        // Options button handler
  $('#options-button').on('click', function(e) {
    e.preventDefault();
    
    // Check permissions via AJAX
    $.ajax({
      url: Drupal.url('files-and-folders/check-options-access'),
      method: 'GET',
      success: function(response) {
        if (response.hasAccess) {
          openOptionsModal();
        } else {
          alert(Drupal.t('You do not have permission to access options.'));
        }
      },
      error: function() {
        alert(Drupal.t('Error checking permissions.'));
      }
    });
  });

        $('.content-area-content')
          .off('click dblclick')
          .on('dblclick', '.folder-item', function(e) {
            e.preventDefault();
            const $item = $(this);
            const itemId = $item.data('item-id');
            
            // Check if this is a folder or file
            if ($item.find('.folder-name').length > 0) {
              // This is a folder, handle folder navigation
              loadFolderContent(itemId);
              updateFolderTreeSelection(itemId);
            } else {
              // This is a file, get file information
              const fileUrl = $item.data('file-url');
              const extension = $item.data('file-extension');
              const name = $item.data('filename');
              
              // Define supported extensions
              const supportedExtensions = [
                'doc', 'docx', 'xls', 'xlsx', 'ppt', 'pptx', // Office documents
                'jpg', 'jpeg', 'png', 'gif', 'webp', // Images
                'pdf', // PDFs
                'csv' // CSV files
              ];
              
              if (extension && supportedExtensions.includes(extension.toLowerCase())) {
                e.stopPropagation();
                updateModal(fileUrl, name, extension);
              }
            }
          })
          .on('click', '.folder-name', function(e) {
            e.preventDefault();
            e.stopPropagation();
            var $folderItem = $(this).closest('.folder-item');
            $('.folder-item').removeClass('selected');
            $folderItem.addClass('selected');
          })
          .on('click', '.file-name', function(e) {
            e.preventDefault();
          })
          .on('click', '.action-edit', function(e) {
            e.preventDefault();
            var $item = $(this).closest('.folder-item, .file-item');
            var itemId = $item.data('item-id');
            var itemType = $item.hasClass('folder-item') ? 'folder' : 'file';
            var itemName = $item.find('.folder-name, .file-name').text().trim();
            openEditModal(itemId, itemName, itemType);
          })   
          .on('click', '.action-delete', function(e) {
            e.preventDefault();
            var itemId = $(this).data('id');
            var itemType = $(this).closest('.folder-item, .file-item').hasClass('folder-item') ? 'folder' : 'file';
            openDeleteModal(itemId, itemType);
          })
          .on('click', '.action-move', function(e) {
            e.preventDefault();
            var itemId = $(this).data('id');
            var itemType = $(this).closest('.folder-item, .file-item').hasClass('folder-item') ? 'folder' : 'file';
            openMoveModal(itemId, itemType);
          })
          .on('click', '.action-download', function(e) {
            e.preventDefault();
            var fileId = $(this).data('id');
            downloadFile(fileId);
          })
          .on('click', '.folder-toggle', function(e) {
            e.stopPropagation();
            var $row = $(this).closest('.folder-item');
            var folderId = $row.find('.folder-name').data('folder-id');
            
            if ($row.next('.subfolder-content').length) {
              $row.next('.subfolder-content').toggle();
              $(this).text(function(_, text) { return text === '▼' ? '▶' : '▼'; });
            } else {
              loadSubfolderContent(folderId, $row);
            }
          });
      
        // Search functionality
        $('#search-button').on('click', function() {
          performSearch();
        });
      
        $('#search-input').on('keypress', function(e) {
          if (e.which === 13) {
            performSearch();
          }
        });
      
        // Close modal handlers
        $('.office-modal-close').on('click', function() {
          $('#office-online-modal').fadeOut(300, function() {
            $('#office-frame').attr('src', '');
            $('#modal-image').attr('src', '');
          });
        });
      
        $(window).on('click', function(e) {
          if ($(e.target).is('#office-online-modal')) {
            $('#office-online-modal').fadeOut(300, function() {
              $('#office-frame').attr('src', '');
              $('#modal-image').attr('src', '');
            });
          }
        });
      }

    function performSearch() {
      var searchTerm = $('#search-input').val();
      var currentFolderId = $('.content-area').data('current-folder-id') || '0';
    
      $.ajax({
        url: Drupal.url('files-and-folders/search-content'),
        method: 'POST',
        data: {
          searchTerm: searchTerm,
          folderId: currentFolderId
        },
        success: function(response) {
          $('.content-area-content').html(response.html);
          initContentAreaEvents();
        },
        error: function(jqXHR, textStatus, errorThrown) {
          console.error('Error searching content:', textStatus, errorThrown);
        }
      });
    }

    function openEditModal(itemId, itemName, itemType) {
      // Close existing dialogs asynchronously
      setTimeout(function() {
        $('.ui-dialog-content').dialog('close');
      }, 0);
    
      // Create modal content asynchronously
      setTimeout(function() {
        var $modal = $('<div id="edit-modal">').dialog({
          title: Drupal.t('Edit @type', {'@type': itemType.charAt(0).toUpperCase() + itemType.slice(1)}),
          width: '90%',
          height: 'auto',
          modal: true,
          dialogClass: 'files-and-folders-dialog',
          close: function() {
            $(this).remove();
          }
        });
    
        if (!itemName) {
          var $item = $('.folder-item[data-item-id="' + itemId + '"], .file-item[data-item-id="' + itemId + '"]');
          itemName = $item.find('.folder-name, .file-name').text().trim();
        }
    
        var $content = $('<div>')
          .append($('<label for="edit-item-name">').text(Drupal.t('Name')))
          .append($('<input id="edit-item-name" type="text">').val(itemName));
    
        $modal.append($content);
    
        $modal.dialog('option', 'buttons', [
          {
            text: Drupal.t('Save'),
            click: function() {
              var newName = $('#edit-item-name').val();
              updateItemName(itemId, newName, itemType);
              $(this).dialog('close');
            }
          },
          {
            text: Drupal.t('Cancel'),
            click: function() {
              $(this).dialog('close');
            }
          }
        ]);
      }, 0);
    }

    function updateItemName(itemId, newName, itemType) {
      $.ajax({
        url: Drupal.url('files-and-folders/ajax/update-item-name'),
        method: 'POST',
        data: {
          item_id: itemId,
          new_name: newName,
          item_type: itemType
        },
        success: function(response) {
          if (response.status === 'success') {
            loadFolderTree();
            loadFolderContent(response.parent_id);
          } else {
            alert(Drupal.t('Error updating @type name: @message', {'@type': itemType, '@message': response.message}));
          }
        },
        error: function() {
          alert(Drupal.t('An error occurred while updating the @type name.', {'@type': itemType}));
        }
      });
    }
    
    function openMoveModal(itemId, itemType) {
      // Close existing dialogs asynchronously
      setTimeout(function() {
        $('.ui-dialog-content').dialog('close');
      }, 0);
    
      // Create modal content asynchronously
      setTimeout(function() {
        var $modal = $('<div id="move-item-modal">').dialog({
          title: Drupal.t('Move @type', {'@type': itemType}),
          width: '90%',
          height: 'auto',
          modal: true,
          dialogClass: 'files-and-folders-dialog',
          close: function() {
            $(this).remove();
          }
        });
    
        var $content = $('<div>')
          .append($('<p>').text(Drupal.t('Select the new parent folder:')))
          .append($('<select id="new-parent-folder">'));
    
        $modal.append($content);
    
        populateFolderOptions(itemId);
    
        $modal.dialog('option', 'buttons', [
          {
            text: Drupal.t('Move'),
            click: function() {
              var newParentId = $('#new-parent-folder').val();
              moveItem(itemId, newParentId, itemType);
              $(this).dialog('close');
            }
          },
          {
            text: Drupal.t('Cancel'),
            click: function() {
              $(this).dialog('close');
            }
          }
        ]);
      }, 0);
    }

    function populateFolderOptions(currentItemId) {
      $.getJSON(Drupal.url('files-and-folders/get-folder-tree'), function(data) {
        var $select = $('#new-parent-folder');
        $select.empty();
        
        function addOptions(folders, level) {
          folders.forEach(function(folder) {
            if (folder.id !== currentItemId) {
              var prefix = new Array(level + 1).join('- ');
              $select.append($('<option>').val(folder.id).text(prefix + folder.name));
              if (folder.children && folder.children.length > 0) {
                addOptions(folder.children, level + 1);
              }
            }
          });
        }
        
        addOptions(data, 0);
    
        if ($select.children().length === 0) {
          $select.append($('<option>').val('').text(Drupal.t('No available folders')));
        }
      }).fail(function(jqXHR, textStatus, errorThrown) {
        console.error('Error loading folder tree:', textStatus, errorThrown);
      });
    }

    function openDeleteModal(itemId, itemType) {
      // Close existing dialogs asynchronously
      setTimeout(function() {
        $('.ui-dialog-content').dialog('close');
      }, 0);
    
      // Create modal content asynchronously
      setTimeout(function() {
        var $modal = $('<div id="delete-modal">').dialog({
          title: Drupal.t('Confirm Deletion'),
          width: '30%',
          height: 'auto',
          modal: true,
          dialogClass: 'files-and-folders-dialog',
          close: function() {
            $(this).remove();
          }
        });
    
        var $content = $('<div>')
          .append($('<p>').text(Drupal.t('Are you sure you want to delete this @type?', {'@type': itemType})));
    
        $modal.append($content);
    
        $modal.dialog('option', 'buttons', [
          {
            text: Drupal.t('Delete'),
            click: function() {
              deleteItem(itemId, itemType);
              $(this).dialog('close');
            }
          },
          {
            text: Drupal.t('Cancel'),
            click: function() {
              $(this).dialog('close');
            }
          }
        ]);
      }, 0);
    }

    function deleteItem(itemId, itemType) {
      $.ajax({
        url: Drupal.url('files-and-folders/ajax/delete-item'),
        method: 'POST',
        data: {
          item_id: itemId,
          item_type: itemType
        },
        success: function(response) {
          if (response.status === 'success') {
            // Refresh both tree and content
            loadFolderTree();
            
            // If parent_id is returned, load that folder's content
            if (response.parent_id) {
              loadFolderContent(response.parent_id);
            } else {
              // Otherwise, load current folder content
              var currentFolderId = $('.content-area').data('current-folder-id') || '0';
              loadFolderContent(currentFolderId);
            }
            
            // Show success message
            showMessage(Drupal.t('Item deleted successfully'), 'status');
          } else {
            showMessage(Drupal.t('Error deleting item: @message', 
              {'@message': response.message}), 'error');
          }
        },
        error: function(jqXHR, textStatus, errorThrown) {
          console.error('Error deleting item:', textStatus, errorThrown);
          showMessage(Drupal.t('An error occurred while deleting the item.'), 'error');
        }
      });
    }
    
    // Helper function to show messages
    function showMessage(message, type) {
      const $message = $('<div>', {
        class: `message message--${type}`,
        text: message
      });
      
      $('.content-area').prepend($message);
      
      // Remove message after 3 seconds
      setTimeout(() => {
        $message.fadeOut(300, function() {
          $(this).remove();
        });
      }, 3000);
    }
    
    function moveItem(itemId, newParentId, itemType) {
      $.ajax({
        url: Drupal.url('files-and-folders/ajax/move-item'),
        method: 'POST',
        data: {
          item_id: itemId,
          new_parent_id: newParentId,
          item_type: itemType
        },
        success: function(response) {
          if (response.status === 'success') {
            loadFolderTree();
            loadFolderContent(newParentId);
          } else {
            alert(Drupal.t('Error moving item: @message', {'@message': response.message}));
          }
        },
        error: function() {
          alert(Drupal.t('An error occurred while moving the item.'));
        }
      });
    }

    function downloadFile(fileId) {
      window.location.href = Drupal.url('files-and-folders/ajax/download/' + fileId);
    }

    function loadSubfolderContent(folderId, $row) {
      $.getJSON(Drupal.url('files-and-folders/get-folder-content/' + folderId), function (data) {
        $row.next('.subfolder-content').remove();
        $row.after('<tr class="subfolder-content"><td colspan="5">' + data.html + '</td></tr>');
        $row.find('.folder-toggle').text('▼');
        initContentAreaEvents();
        applyCurrentIconSize();
        // Do not navigate or select the subfolder here
      });
    }

    function loadFolderContent(folderId) {
      $.getJSON(Drupal.url('files-and-folders/get-folder-content/' + folderId), function(data) {
        $('.content-area-content').html(data.html);
        $('.content-area-title').text(data.folderName);
        $('.content-area').data('current-folder-id', folderId);
        initContentAreaEvents();
        applyCurrentLayout();
        applyCurrentIconSize();
        initKebabMenu();
        // Do not add 'selected' class here
      }).fail(function(jqXHR, textStatus, errorThrown) {
        console.error('Error loading folder content:', textStatus, errorThrown);
        $('.content-area-content').html('<p>Error loading folder content.</p>');
      });
    }
    
    function applyIconSize(size) {
      $('.folder-icon, .file-icon, #folder-tree-container .folder-icon, .subfolder-content .folder-icon, .subfolder-content .file-icon')
        .removeClass('icon-size-small icon-size-medium icon-size-large')
        .addClass('icon-size-' + size);
      $('.content-area-content, #folder-tree-container, .subfolder-content').attr('data-icon-size', size);
    }
    
    function applyCurrentIconSize() {
      var currentSize = $('.content-area-content').attr('data-icon-size') || 'medium';
      applyIconSize(currentSize);
    }

    function applyCurrentLayout() {
      var currentLayout = $('.content-area-content').attr('data-layout') || 'list';
      $('.content-area-content').attr('data-layout', currentLayout);
      
      // Adjust thumbnails based on layout
      if (currentLayout === 'list') {
        $('.file-thumbnail').css({
          'width': '48px',
          'height': '48px'
        });
      } else if (currentLayout === 'big-icons') {
        $('.file-thumbnail').css({
          'width': '128px',
          'height': '128px'
        });
      } else if (currentLayout === 'medium-icons') {
        $('.file-thumbnail').css({
          'width': '64px',
          'height': '64px'
        });
      }
    }
  

    function updateFolderTreeSelection(folderId) {
      // Store the expanded state
      var expandedFolders = $('.folder-item.expanded').map(function() {
        return $(this).data('folder-id');
      }).get();
    
      $('.folder-item').removeClass('selected expanded');
      var $selectedFolder = $('.folder-item[data-folder-id="' + folderId + '"]');
      $selectedFolder.addClass('selected');
      $selectedFolder.parents('.folder-item').addClass('expanded');
    
      // Reapply the expanded state
      expandedFolders.forEach(function(id) {
        $('.folder-item[data-folder-id="' + id + '"]').addClass('expanded');
      });
    
      // Show/hide subfolders based on expanded state
      $('.folder-item').each(function() {
        var $toggle = $(this).find('> .folder-toggle');
        var $subfolders = $(this).find('> .subfolder-list');
        if ($(this).hasClass('expanded')) {
          $toggle.text('▼');
          $subfolders.show();
        } else {
          $toggle.text('▶');
          $subfolders.hide();
        }
      });
    }

      function createFolder() {
        var $modal = $('<div id="create-folder-modal"></div>').dialog({
          title: Drupal.t('Create New Folder'),
          width: '90%',
          height: 'auto',
          modal: true,
          dialogClass: 'files-and-folders-dialog',
          close: function() {
            $(this).remove();
          }
        });
      
        var $content = $('<div>')
          .append($('<label for="new-folder-name">').text(Drupal.t('Folder Name')))
          .append($('<input id="new-folder-name" type="text">').attr('placeholder', Drupal.t('Enter folder name')))
          .append($('<label for="parent-folder">').text(Drupal.t('Parent Folder')))
          .append($('<select id="parent-folder">'))
          .append($('<label for="folder-visibility">').text(Drupal.t('Visibility')))
          .append($('<select id="folder-visibility">')
            .append($('<option>').val('public').text(Drupal.t('Public')))
            .append($('<option>').val('private').text(Drupal.t('Private')))
            .append($('<option>').val('shared').text(Drupal.t('Shared')))
          );
      
        $modal.append($content);
      
        populateParentFolderOptions();
      
        $modal.dialog('option', 'buttons', [
          {
            text: Drupal.t('Create'),
            click: function() {
              var folderName = $('#new-folder-name').val();
              var parentId = $('#parent-folder').val();
              var visibility = $('#folder-visibility').val();
              
              $.ajax({
                url: Drupal.url('files-and-folders/ajax/create-folder'),
                method: 'POST',
                data: {
                  name: folderName,
                  parent_id: parentId,
                  visibility: visibility
                },
                success: function(response) {
                  if (response.status === 'success') {
                    $modal.dialog('close');
                    loadFolderContent(parentId);
                    refreshFolderStructure();
                  } else {
                    alert(Drupal.t('Error creating folder: @message', {'@message': response.message}));
                  }
                },
                error: function(jqXHR, textStatus, errorThrown) {
                  console.error('Error creating folder:', jqXHR.responseText);
                  alert(Drupal.t('An error occurred while creating the folder.'));
                }
              });
            }
          },
          {
            text: Drupal.t('Cancel'),
            click: function() {
              $(this).dialog('close');
            }
          }
        ]);
      }

      function populateParentFolderOptions() {
        $.getJSON(Drupal.url('files-and-folders/get-folder-tree'), function(data) {
          var $select = $('#parent-folder');
          $select.empty();
          
          function addOptions(folders, level) {
            folders.forEach(function(folder) {
              var prefix = new Array(level + 1).join('- ');
              $select.append($('<option>').val(folder.id).text(prefix + folder.name));
              if (folder.children && folder.children.length > 0) {
                addOptions(folder.children, level + 1);
              }
            });
          }
          
          addOptions(data, 0);
        }).fail(function(jqXHR, textStatus, errorThrown) {
          console.error('Error loading folder tree:', textStatus, errorThrown);
        });
      }

      function initAddFilesButton() {
        $('.add-files').on('click', function(e) {
          e.preventDefault();
          openAddFilesModal();
        });
      
        function openAddFilesModal() {
          // Clear any existing files array
          window.files = [];
          
          var $modal = $('<div id="add-files-modal">').dialog({
            title: Drupal.t('Add Files'),
            width: '90%',
            height: 'auto',
            modal: true,
            dialogClass: 'files-and-folders-dialog',
            close: function() {
              // Clear files on modal close
              if (window.clearFileSelection) {
                window.clearFileSelection();
              }
              $(this).remove();
            }
          });

          var $content = $('<div>')
            .append($('<label for="parent-folder">').text(Drupal.t('Parent Folder')))
            .append($('<select id="parent-folder" name="parent_folder">'))
            .append($('<label for="file-visibility">').text(Drupal.t('Visibility')))
            .append($('<select id="file-visibility">')
              .append($('<option>').val('public').text(Drupal.t('Public')))
              .append($('<option>').val('private').text(Drupal.t('Private')))
              .append($('<option>').val('shared').text(Drupal.t('Shared')))
            )
            .append($('<div id="drop-zone">')
              .append($('<p>').text(Drupal.t('Drag & drop files or folders here or click to select')))
              .append($('<input type="file" id="file-input" multiple>').css('display', 'none'))
            )
            .append($('<div id="file-list">'))
            .append($('<div class="upload-progress">').hide());
        
          $modal.append($content);
          populateParentFolderOptions();
          
          // Initialize drop zone with file handling
          const dropZone = document.getElementById('drop-zone');
          const fileInput = document.getElementById('file-input');
          const fileList = document.getElementById('file-list');
        
          // Enable folder selection
          fileInput.setAttribute('webkitdirectory', '');
          fileInput.setAttribute('directory', '');
        
          function clearFileSelection() {
            window.files = [];
            if (fileInput) fileInput.value = '';
            if (fileList) fileList.innerHTML = '';
          }
        
          dropZone.addEventListener('click', () => fileInput.click());
        
          dropZone.addEventListener('dragover', (e) => {
            e.preventDefault();
            e.stopPropagation();
            dropZone.classList.add('dragover');
          });
        
          dropZone.addEventListener('dragleave', (e) => {
            e.preventDefault();
            e.stopPropagation();
            dropZone.classList.remove('dragover');
          });
        
          dropZone.addEventListener('drop', async (e) => {
            e.preventDefault();
            e.stopPropagation();
            dropZone.classList.remove('dragover');
            const items = e.dataTransfer.items;
            await handleItems(items);
          });
        
          fileInput.addEventListener('change', (e) => {
            handleFiles(Array.from(e.target.files));
          });
        
          async function handleItems(items) {
            const entries = [];
            for (let item of items) {
              if (item.kind === 'file') {
                const entry = item.webkitGetAsEntry();
                if (entry) {
                  entries.push(entry);
                }
              }
            }
            
            const files = [];
            await Promise.all(entries.map(entry => readEntry(entry, '', files)));
            handleFiles(files);
          }
        
          async function readEntry(entry, path, files) {
            if (entry.isFile) {
              const file = await new Promise((resolve) => entry.file(resolve));
              file.relativePath = path + file.name;
              files.push(file);
            } else if (entry.isDirectory) {
              const dirReader = entry.createReader();
              const entries = await new Promise((resolve) => {
                dirReader.readEntries((entries) => resolve(entries));
              });
              
              const newPath = path + entry.name + '/';
              await Promise.all(entries.map(entry => readEntry(entry, newPath, files)));
            }
          }
        
          function handleFiles(newFiles) {
            window.files = [...(window.files || []), ...newFiles];
            updateFileList();
          }
        
          function updateFileList() {
            fileList.innerHTML = '';
            window.files.forEach((file, index) => {
              const fileItem = $('<div>')
                .addClass('file-item')
                .append($('<span>').text(file.relativePath || file.webkitRelativePath || file.name))
                .append($('<button>')
                  .addClass('remove-file')
                  .text('Remove')
                  .click(() => removeFile(index)));
              $(fileList).append(fileItem);
            });
          }
        
          function removeFile(index) {
            window.files.splice(index, 1);
            updateFileList();
          }
        
          // Initialize drop zone and store the returned functions
          const dropZoneFunctions = initializeDropZone();
          
          // Add modal buttons
          $modal.dialog('option', 'buttons', [
            {
              text: Drupal.t('Upload'),
              click: function() {
                if (window.files && window.files.length > 0) {
                  uploadFiles();
                  $(this).dialog('close');
                } else {
                  alert(Drupal.t('Please select files to upload'));
                }
              }
            },
            {
              text: Drupal.t('Cancel'),
              click: function() {
                $(this).dialog('close');
              }
            }
          ]);
        

  populateParentFolderOptions();
  initializeDropZone();
}
      
        function populateParentFolderOptions() {
          $.getJSON(Drupal.url('files-and-folders/get-folder-tree'), function(data) {
            var $select = $('#parent-folder');
            $select.empty();
            
            function addOptions(folders, level) {
              folders.forEach(function(folder) {
                var prefix = new Array(level + 1).join('- ');
                $select.append($('<option>').val(folder.id).text(prefix + folder.name));
                if (folder.children && folder.children.length > 0) {
                  addOptions(folder.children, level + 1);
                }
              });
            }
            
            addOptions(data, 0);
          }).fail(function(jqXHR, textStatus, errorThrown) {
            console.error('Error loading folder tree:', textStatus, errorThrown);
          });
        }
        
        let files = [];

        function initializeDropZone() {
          const dropZone = document.getElementById('drop-zone');
          const fileInput = document.getElementById('file-input');
          const fileList = document.getElementById('file-list');
        
          // Initialize files array if not exists
          window.files = [];
        
          // Enable folder selection
          fileInput.setAttribute('webkitdirectory', '');
          fileInput.setAttribute('directory', '');
        
          // Define clearFileSelection function first
          function clearFileSelection() {
            window.files = [];
            if (fileInput) fileInput.value = '';
            if (fileList) fileList.innerHTML = '';
          }
        
          // Make clearFileSelection available globally
          window.clearFileSelection = clearFileSelection;
        
          dropZone.addEventListener('click', () => fileInput.click());
        
          dropZone.addEventListener('dragover', (e) => {
            e.preventDefault();
            e.stopPropagation();
            dropZone.classList.add('dragover');
          });
        
          dropZone.addEventListener('dragleave', (e) => {
            e.preventDefault();
            e.stopPropagation();
            dropZone.classList.remove('dragover');
          });
        
          dropZone.addEventListener('drop', async (e) => {
            e.preventDefault();
            e.stopPropagation();
            dropZone.classList.remove('dragover');
            
            // Clear existing files before adding new ones
            clearFileSelection();
            
            const items = e.dataTransfer.items;
            await handleItems(items);
          });
        
          fileInput.addEventListener('change', (e) => {
            // Clear existing files before adding new ones
            clearFileSelection();
            handleFiles(Array.from(e.target.files));
          });
        
          async function handleItems(items) {
            const entries = [];
            for (let item of items) {
              if (item.kind === 'file') {
                const entry = item.webkitGetAsEntry();
                if (entry) {
                  entries.push(entry);
                }
              }
            }
            
            const files = [];
            await Promise.all(entries.map(entry => readEntry(entry, '', files)));
            handleFiles(files);
          }
        
          async function readEntry(entry, path, files) {
            if (entry.isFile) {
              const file = await new Promise((resolve) => entry.file(resolve));
              file.relativePath = path + file.name;
              files.push(file);
            } else if (entry.isDirectory) {
              const dirReader = entry.createReader();
              const entries = await new Promise((resolve) => {
                dirReader.readEntries((entries) => resolve(entries));
              });
              
              const newPath = path + entry.name + '/';
              await Promise.all(entries.map(entry => readEntry(entry, newPath, files)));
            }
          }
        
          function handleFiles(newFiles) {
            window.files = [...newFiles];
            updateFileList();
          }
        
          function updateFileList() {
            fileList.innerHTML = '';
            window.files.forEach((file, index) => {
              const fileItem = $('<div>')
                .addClass('file-item')
                .append($('<span>').text(file.relativePath || file.webkitRelativePath || file.name))
                .append($('<button>')
                  .addClass('remove-file')
                  .text('Remove')
                  .click(() => removeFile(index)));
              $(fileList).append(fileItem);
            });
          }
        
          function removeFile(index) {
            window.files.splice(index, 1);
            updateFileList();
          }
        
          // Return the clearFileSelection function for external use
          return { clearFileSelection };
        }
        
      
        function initDeleteButton() {
          $('.action-delete').on('click', function(e) {
            e.preventDefault();
            DeleteModal($(this).data('id'));
          });
        }

        function DeleteModal(itemId, itemType) {
          $('.ui-dialog-content').dialog('close');
        
          var $modal = $('<div id="delete-modal">').dialog({
            title: Drupal.t('Confirm Deletion'),
            width: '400px',
            height: 'auto',
            modal: true,
            dialogClass: 'files-and-folders-dialog',
            close: function() {
              $(this).remove();
            }
          });
        
          var $content = $('<div>')
            .append($('<p>').text(Drupal.t('Are you sure you want to delete this item? This action cannot be undone.')))
            .append($('<div id="delete-buttons">')
              .append($('<button>')
                .text(Drupal.t('Delete'))
                .addClass('button button--danger')
                .click(function() {
                  deleteItem(itemId, itemType);
                  $modal.dialog('close');
                }))
              .append($('<button>')
                .text(Drupal.t('Cancel'))
                .addClass('button')
                .click(function() {
                  $modal.dialog('close');
                }))
            );
        
          $modal.append($content);
        }
        
        function uploadFiles() {
          var parentFolderId = $('#parent-folder').val();
          var visibility = $('#file-visibility').val();
          var formData = new FormData();
          
          formData.append('parent_id', parentFolderId);
          formData.append('visibility', visibility);
        
          window.files.forEach((file, index) => {
            const relativePath = file.relativePath || file.webkitRelativePath || file.name;
            formData.append('files[]', file);
            formData.append('paths[]', relativePath);
          });
        
          $('.upload-progress').show().text(Drupal.t('Uploading...'));
        
          $.ajax({
            url: Drupal.url('files-and-folders/ajax/upload-files'),
            type: 'POST',
            data: formData,
            processData: false,
            contentType: false,
            success: function(response) {
              if (response.status === 'success') {
                // Clear the files array and UI
                window.files = [];
                $('#file-list').empty();
                
                // Refresh the view
                loadFolderTree();
                loadFolderContent(parentFolderId);
                
                // Show success message
                alert(Drupal.t('Files uploaded successfully'));
              } else {
                alert(Drupal.t('Error uploading files: @message', {'@message': response.message}));
              }
            },
            error: function() {
              alert(Drupal.t('An error occurred while uploading files.'));
            },
            complete: function() {
              $('.upload-progress').hide();
            }
          });
        }
      }  
    }
  };
})(jQuery, Drupal, once);