<?php

namespace Drupal\file_folder_manager\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\CloseModalDialogCommand;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\file_folder_manager\Controller\FileFolderController;

class FileForm extends FormBase {

  public function getFormId() {
    return 'file_folder_manager_file_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('File Name'),
      '#required' => TRUE,
    ];

    $form['parent'] = [
      '#type' => 'entity_autocomplete',
      '#title' => $this->t('Parent Folder'),
      '#target_type' => 'node',
      '#selection_settings' => [
        'target_bundles' => ['folder'],
      ],
      '#required' => TRUE,
    ];

    $form['file'] = [
      '#type' => 'managed_file',
      '#title' => $this->t('File'),
      '#upload_location' => 'public://file_folder_manager/',
      '#required' => TRUE,
    ];

    $form['file_type'] = [
      '#type' => 'select',
      '#title' => $this->t('File Type'),
      '#options' => [
        'document' => $this->t('Document'),
        'video' => $this->t('Video'),
        'audio' => $this->t('Audio'),
        'image' => $this->t('Image'),
      ],
      '#required' => TRUE,
    ];

    $form['visibility'] = [
      '#type' => 'select',
      '#title' => $this->t('Visibility'),
      '#options' => [
        'public' => $this->t('Public'),
        'private' => $this->t('Private'),
        'shared' => $this->t('Shared'),
      ],
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Upload File'),
      '#ajax' => [
        'callback' => '::submitFormAjax',
      ],
    ];

    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $file = \Drupal\file\Entity\File::load($form_state->getValue('file')[0]);
    $file->setPermanent();
    $file->save();

    $node = \Drupal\node\Entity\Node::create([
      'type' => 'file',
      'title' => $form_state->getValue('name'),
      'field_parent' => $form_state->getValue('parent'),
      'field_file_size' => $file->getSize(),
      'field_file_type' => $form_state->getValue('file_type'),
      'field_visibility' => $form_state->getValue('visibility'),
      'field_file' => [
        'target_id' => $file->id(),
      ],
    ]);
    $node->save();

    $this->messenger()->addMessage($this->t('File uploaded successfully.'));
  }

  public function submitFormAjax(array &$form, FormStateInterface $form_state) {
    $response = new AjaxResponse();
    $response->addCommand(new CloseModalDialogCommand());
    $response->addCommand(new ReplaceCommand('.content-area', FileFolderController::getFolderContent($form_state->getValue('parent'))));
    return $response;
  }
}